# harlequin-datafusion

[![Downloads](https://static.pepy.tech/badge/harlequin-datafusion)](https://pepy.tech/project/harlequin-datafusion)
![PyPI - Version](https://img.shields.io/pypi/v/harlequin-datafusion)
![GitHub License](https://img.shields.io/github/license/mesejo/datafusion-adapter)
![PyPI - Status](https://img.shields.io/pypi/status/harlequin-datafusion)


This repo provides the [Harlequin](https://harlequin.sh) adapter for [DataFusion](https://datafusion.apache.org/) 

## Installation

harlequin-datafusion is available as [`harlequin-datafusion`](https://pypi.org/project/harlequin-datafusion/) on PyPI:

```shell
pip install harlequin-datafusion
```

## Usage
After installation, you can use it as follows

 ```shell
harlequin -a datafusion
```

## Harlequin
For more information on how to use Harlequin, please refer to the [docs](https://harlequin.sh/docs/getting-started) 

## Support

If you have any issues with this repository, please don't hesitate to [raise them](https://github.com/mesejo/datafusion-adapter/issues/new).
It is actively maintained, and we will do our best to help you.

## Acknowledgements

This project was generated from the [harlequin-adapter-template](https://github.com/tconbeer/harlequin-adapter-template) and draws inspiration 
from the [harlequin-adbc](https://github.com/TylerHillery/harlequin-adbc) adapter.    

## Liked the work?

If you've found this repository helpful, why not give it a star? It's an easy way to show your appreciation and support for the project.
Plus, it helps others discover it too!

## License

This repository is licensed under the [MIT License](https://github.com/mesejo/datafusion-adapter/blob/main/LICENSE)

